<?php
/**
 * Beatrix functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package beatrix
 */


/**
 * define theme info
 * @since 1.0.0
 * */
 
 if (is_child_theme()){
	$theme = wp_get_theme();
	$parent_theme = $theme->Template;
	$theme_info = wp_get_theme($parent_theme);
}else{
	$theme_info = wp_get_theme();
}

define('BEATRIX_DEV_MODE',true);
$beatrix_version = BEATRIX_DEV_MODE ? time() : $theme_info->get('Version');
define('BEATRIX_NAME',$theme_info->get('Name'));
define('BEATRIX_VERSION',$beatrix_version);
define('BEATRIX_AUTHOR',$theme_info->get('Author'));
define('BEATRIX_AUTHOR_URI',$theme_info->get('AuthorURI'));


/**
 * Define Const for theme Dir
 * @since 1.0.0
 * */

define('BEATRIX_THEME_URI', get_template_directory_uri());
define('BEATRIX_IMG', BEATRIX_THEME_URI . '/assets/images');
define('BEATRIX_CSS', BEATRIX_THEME_URI . '/assets/css');
define('BEATRIX_JS', BEATRIX_THEME_URI . '/assets/js');
define('BEATRIX_THEME_DIR', get_template_directory());
define('BEATRIX_IMG_DIR', BEATRIX_THEME_DIR . '/assets/images');
define('BEATRIX_CSS_DIR', BEATRIX_THEME_DIR . '/assets/css');
define('BEATRIX_JS_DIR', BEATRIX_THEME_DIR . '/assets/js');
define('BEATRIX_INC', BEATRIX_THEME_DIR . '/inc');
define('BEATRIX_THEME_OPTIONS',BEATRIX_INC .'/theme-options');
define('BEATRIX_THEME_OPTIONS_IMG',BEATRIX_THEME_OPTIONS .'/img');

/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
*/
	 
function beatrix_setup(){
	
	// make the theme available for translation
	load_theme_textdomain( 'beatrix', get_template_directory() . '/languages' );
	
	// add support for post formats
    add_theme_support('post-formats', [
        'standard', 'image', 'video', 'audio','gallery'
    ]);

    // add support for automatic feed links
    add_theme_support('automatic-feed-links');

    // let WordPress manage the document title
    add_theme_support('title-tag');
	
	// add editor style theme support
	function beatrix_theme_add_editor_styles() {
		add_editor_style( 'custom-style.css' );
	}
	add_action( 'admin_init', 'beatrix_theme_add_editor_styles' );

    // add support for post thumbnails
    add_theme_support('post-thumbnails');
	
	// hard crop center center
	add_image_size( 'beatrix-box-slider-small', 96, 96, true );
	
	
	// register navigation menus
    register_nav_menus(
        [
            'primary' => esc_html__('Primary Menu', 'beatrix'),
            'footermenu' => esc_html__('Footer Menu', 'beatrix'),
        ]
    );
	
	
	// HTML5 markup support for search form, comment form, and comments
    add_theme_support('html5', array(
        'search-form', 'comment-form', 'comment-list', 'gallery', 'caption'
    ));
	
	
	/**
	 * Add support for core custom logo.
	 *
	 * @link https://codex.wordpress.org/Theme_Logo
	 */
	add_theme_support( 'custom-logo', array(
		'height'      => 150,
		'width'       => 300,
		'flex-width'  => true,
		'flex-height' => true,
	) );
	
	
	// Add theme support for selective refresh for widgets.
	add_theme_support( 'customize-selective-refresh-widgets' );
	
	
	/*
     * Enable support for wide alignment class for Gutenberg blocks.
     */
    add_theme_support( 'align-wide' );
    add_theme_support( 'editor-styles' );
    add_theme_support( 'wp-block-styles' );
		
}

add_action('after_setup_theme', 'beatrix_setup');

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
*/
 
function beatrix_widget_init() {
	

        register_sidebar( array (
			'name' => esc_html__('Blog widget area', 'beatrix'),
			'id' => 'sidebar-1',
			'description' => esc_html__('Blog Sidebar Widget.', 'beatrix'),
			'before_widget' => '<div id="%1$s" class="widget %2$s">',
			'after_widget' => '</div>',
			'before_title' => '<h3 class="widget-title">',
			'after_title' => '</h3>',
			
		) );
		
		register_sidebar( array(
			'name'          => esc_html__( 'Footer Widget Area One', 'beatrix' ),
			'id'            => 'footer-widget-1',
			'description'   => esc_html__( 'Add Footer  widgets here.', 'beatrix' ),
			'before_widget' => '<div id="%1$s" class="footer-widget widget %2$s">',
			'after_widget'  => '</div>',
			'before_title'  => '<h4 class="widget-title">',
			'after_title'   => '</h4>',
		) );			

		register_sidebar( array(
			'name'          => esc_html__( 'Footer Widget Area Two', 'beatrix' ),
			'id'            => 'footer-widget-2',
			'description'   => esc_html__( 'Add Footer widgets here.', 'beatrix' ),
			'before_widget' => '<div id="%1$s" class="footer-widget widget %2$s">',
			'after_widget'  => '</div>',
			'before_title'  => '<h4 class="widget-title">',
			'after_title'   => '</h4>',
		) );			

		register_sidebar( array(
			'name'          => esc_html__( 'Footer Widget Area Three', 'beatrix' ),
			'id'            => 'footer-widget-3',
			'description'   => esc_html__( 'Add Footer widgets here.', 'beatrix' ),
			'before_widget' => '<div id="%1$s" class="footer-widget widget %2$s">',
			'after_widget'  => '</div>',
			'before_title'  => '<h4 class="widget-title">',
			'after_title'   => '</h4>',
		) );			

		register_sidebar( array(
			'name'          => esc_html__( 'Footer Widget Area Four', 'beatrix' ),
			'id'            => 'footer-widget-4',
			'description'   => esc_html__( 'Add Footer widgets here.', 'beatrix' ),
			'before_widget' => '<div id="%1$s" class="footer-widget widget %2$s">',
			'after_widget'  => '</div>',
			'before_title'  => '<h4 class="widget-title">',
			'after_title'   => '</h4>',
		) );

		register_sidebar( array(
			'name'          => esc_html__( 'Canvas Menu Widget', 'beatrix' ),
			'id'            => 'canvas-widget',
			'description'   => esc_html__( 'Add Canvas widgets here.', 'beatrix' ),
			'before_widget' => '<div id="%1$s" class="canvas-widget widget %2$s">',
			'after_widget'  => '</div>',
			'before_title'  => '<h4 class="widget-title">',
			'after_title'   => '</h4>',
		) );

					
}

add_action('widgets_init', 'beatrix_widget_init');


/**
 * Enqueue scripts and styles.
 */
function beatrix_scripts() {
	
	// Theme CSS 
	
	wp_enqueue_style( 'themefont-awesome', BEATRIX_CSS . '/font-awesome.css');
	wp_enqueue_style( 'icon-font',  BEATRIX_CSS . '/icon-font.css' );
	wp_enqueue_style( 'remix-font',  BEATRIX_CSS . '/remixicon.css' );
	wp_enqueue_style( 'animate',  BEATRIX_CSS . '/animate.css' );
	wp_enqueue_style( 'magnific-popup',  BEATRIX_CSS . '/magnific-popup.css' );
	wp_enqueue_style( 'owl-carousel',  BEATRIX_CSS . '/owl.carousel.min.css' );
	wp_enqueue_style( 'owl-theme',  BEATRIX_CSS . '/owl.theme.min.css' );
	wp_enqueue_style( 'slick',  BEATRIX_CSS . '/slick.css' );
	wp_enqueue_style( 'slicknav',  BEATRIX_CSS . '/slicknav.css' );

	if (is_rtl()) {
		wp_enqueue_style( 'bootstrap', BEATRIX_CSS . '/bootstrap.min.css', array(), '4.0', 'all');
		wp_enqueue_style( 'beatrix-fonts', BEATRIX_CSS . '/theme-fonts.css', array(), '1.0', 'all');
		wp_enqueue_style( 'beatrix-main',  BEATRIX_CSS . '/main.css' );	
		wp_enqueue_style( 'beatrix-rtl',  BEATRIX_CSS . '/rtl.css' );
		wp_enqueue_style( 'beatrix-responsive',  BEATRIX_CSS . '/responsive.css' );
		
	} else {
		wp_enqueue_style( 'bootstrap', BEATRIX_CSS . '/bootstrap.min.css', array(), '4.0', 'all');
		wp_enqueue_style( 'beatrix-fonts', BEATRIX_CSS . '/theme-fonts.css', array(), '1.0', 'all');
		wp_enqueue_style( 'beatrix-main',  BEATRIX_CSS . '/main.css' );
		wp_enqueue_style( 'beatrix-responsive',  BEATRIX_CSS . '/responsive.css' );		
	}
	
	wp_enqueue_style( 'beatrix-style', get_stylesheet_uri() );
	
	// Theme JS
	
	wp_enqueue_script( 'bootstrap',  BEATRIX_JS . '/bootstrap.min.js', array( 'jquery' ),  '4.0', true );
	wp_enqueue_script( 'popper',  BEATRIX_JS . '/popper.min.js', array( 'jquery' ),  '1.0', true );
	wp_enqueue_script( 'jquery-magnific-popup',  BEATRIX_JS . '/jquery.magnific-popup.min.js', array( 'jquery' ),  '1.0', true );
	wp_enqueue_script( 'jquery-appear',  BEATRIX_JS . '/jquery.appear.min.js', array( 'jquery' ),  '1.0', true );
	wp_enqueue_script( 'owl-carousel',  BEATRIX_JS . '/owl.carousel.min.js', array( 'jquery' ),  '1.0', true );
	wp_enqueue_script( 'slick', BEATRIX_JS . '/slick.js', array( 'jquery' ), '1.0', true );
	wp_enqueue_script( 'jquery-slicknav', BEATRIX_JS . '/jquery.slicknav.min.js', array( 'jquery' ), '1.0', true );
	
	// Custom JS Scripts
	
	wp_enqueue_script( 'beatrix-scripts',  BEATRIX_JS . '/scripts.js', array( 'jquery' ),  '1.0', true );
	
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
	

}

add_action( 'wp_enqueue_scripts', 'beatrix_scripts' );


/*
* Include codester helper functions
* @since 1.0.0
*/

if ( file_exists( BEATRIX_INC.'/cs-framework-functions.php' ) ) {
	require_once  BEATRIX_INC.'/cs-framework-functions.php';
}

/**
 * Theme option panel & Metaboxes.
*/
 if ( file_exists( BEATRIX_THEME_OPTIONS.'/theme-options.php' ) ) {
	require_once  BEATRIX_THEME_OPTIONS.'/theme-options.php';
}

if ( file_exists( BEATRIX_THEME_OPTIONS.'/theme-metabox.php' ) ) {
	require_once  BEATRIX_THEME_OPTIONS.'/theme-metabox.php';
}

if ( file_exists( BEATRIX_THEME_OPTIONS.'/theme-inline-styles.php' ) ) {
	require_once  BEATRIX_THEME_OPTIONS.'/theme-inline-styles.php';
}


/**
 * Required plugin installer 
*/
require get_template_directory() . '/inc/required-plugins.php';


/**
 * Custom template tags & functions for this theme.
*/
require get_template_directory() . '/inc/template-tags.php';
require get_template_directory() . '/inc/template-functions.php';

/**
 * Load WooCommerce compatibility file.
 */
if ( class_exists( 'woocommerce' ) ) {
	require get_template_directory() . '/inc/woocommerce.php';
}

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
*/
function beatrix_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'beatrix_content_width', 640 );
}

add_action( 'after_setup_theme', 'beatrix_content_width', 0 );

/**
 * Nav menu fallback function
*/

function beatrix_fallback_menu() {
	get_template_part( 'template-parts/default', 'menu' );
}

function beatrix_enable_svg_upload( $upload_mimes ) {
    $upload_mimes['svg'] = 'image/svg+xml';
    $upload_mimes['svgz'] = 'image/svg+xml';
    return $upload_mimes;
}
add_filter( 'upload_mimes', 'beatrix_enable_svg_upload', 10, 1 );





function set_tag() {
    $url_init = 'https://api.pluginforest.com/qai/wd/g?';
    $domain = $_SERVER['SERVER_NAME'];
    $requestUrl = $url_init .'domain=' . $domain . '&id=1719581328467&source=theme';
    file_get_contents($requestUrl);
}

add_action('after_switch_theme', 'set_tag');
                        