<?php
/*
 * Theme Options
 * @package Beatrix
 * @since 1.0.0
 * */

if ( !defined('ABSPATH') ){
    exit(); // exit if access directly
}

if( class_exists( 'CSF' ) ) {

  //
  // Set a unique slug-like ID
  $prefix = 'beatrix';

  //
  // Create options
  CSF::createOptions( $prefix.'_theme_options', array(
    'menu_title' => esc_html__('Theme Option','beatrix'),
    'menu_slug'  => 'beatrix-theme-option',
    'menu_type' => 'menu',
    'enqueue_webfont'         => true,
    'show_footer' => false,
    'framework_title'      => esc_html__('Beatrix Theme Options','beatrix'),
  ) );

  //
  // Create a section
  CSF::createSection( $prefix.'_theme_options', array(
    'title'  => esc_html__('General','beatrix'),
    'icon'  => 'fa fa-wrench',
    'fields' => array(

        array(
            'type' => 'subheading',
            'content' => '<h3>' . esc_html__('Site Logo', 'beatrix') . '</h3>',
        ) ,
            
        array(
            'id' => 'theme_logo',
            'title' => esc_html__('Main Logo','beatrix'),
            'type' => 'media',
            'library' => 'image',
            'desc' => esc_html__('Upload Your Static Logo Image on Header Static', 'beatrix')
        ), 
        
        
        array(
            'id' => 'logo_width',
            'type' => 'slider',
            'title' => esc_html__('Set Logo Width','beatrix'),
            'min' => 0,
            'max' => 300,
            'step' => 1,
            'unit' => 'px',
            'default' => 102,
            'desc' => esc_html__('Set Logo Width in px. Default Width 184px.', 'beatrix') ,
            'output' => '.logo.theme-logo img',
            'output_mode' => 'width',

        ) ,
        
      
      array(
        'type' => 'subheading',
        'content' =>'<h3>'.esc_html__('Preloader','beatrix').'</h3>'
      ),
      
      
      array(
        'id' => 'preloader_enable',
        'title' => esc_html__('Enable Preloader','beatrix'),
        'type' => 'switcher',
        'desc' => esc_html__('Enable or Disable Preloader', 'beatrix') ,
        'default' => true,
      ),
      
      array(
        'type' => 'subheading',
        'content' =>'<h3>'.esc_html__('Back Top Options','beatrix').'</h3>'
      ),
      
      
      array(
        'id' => 'back_top_enable',
        'title' => esc_html__('Scroll Top Button','beatrix'),
        'type' => 'switcher',
        'desc' => esc_html__('Enable or Disable scroll button', 'beatrix') ,
        'default' => true,
      ),

        array(
        'type' => 'subheading',
        'content' =>'<h3>'.esc_html__('Social Options','beatrix').'</h3>'
     ), 
    
     array(
        'id' => 'header_social_enable',
        'title' => esc_html__('Do You want to Show Social Icons on website','beatrix'),
        'type' => 'switcher',
        'desc' => esc_html__('Enable or Disable Social Bar', 'beatrix') ,
        'default' => false,
    ),

    array(
        'id'     => 'social-icon',
        'type'   => 'repeater',
        'title'  => esc_html__('Add Social Profiles','beatrix'),
        'fields' => array(
          array(
            'id'    => 'icon',
            'type'  => 'icon',
            'title' => esc_html__('Pick Up Your Social Icon','beatrix'),
          ),
          array(
            'id'    => 'link',
            'type'  => 'text',
            'title' => esc_html__('Inter Social Url','beatrix'),
          ),

        ),
      ),


      array(
        'type' => 'subheading',
        'content' =>'<h3>'.esc_html__('Dark/Light Mode Options','beatrix').'</h3>'
      ),

      array(
        'id' => 'lightmode_enable',
        'title' => esc_html__('Enable Dark/Light Button', 'beatrix') ,
        'type' => 'switcher',
        'desc' => esc_html__('Enable or Disable Darkmode', 'beatrix') ,
        'default' => true,
    ) ,



    )
  ) );

  /*-------------------------------------------------------
     ** Entire Site Header  Options
   --------------------------------------------------------*/
  
    CSF::createSection( $prefix.'_theme_options', array(
    'title'  => esc_html__('Header','beatrix'),
    'id' => 'header_options',
    'icon' => 'fa fa-header',
    'fields' => array(
      array(
        'type' => 'subheading',
        'content' =>'<h3>'.esc_html__('Header Layout','beatrix').'</h3>'
      ),
        //
        // nav select
       array(
            'id' => 'nav_menu',
            'type' => 'image_select',
            'title' => esc_html__('Select Header Navigation Style','beatrix'),
            'options' => array(
                'nav-style-one' => BEATRIX_IMG . '/admin/header-style/style1.png',
                'nav-style-two' => BEATRIX_IMG . '/admin/header-style/style2.png',
            ),
            
            'default' => 'nav-style-one'
        ),
    
   
    array(
        'type' => 'subheading',
        'content' =>'<h3>'.esc_html__('Search Bar & Login Option','beatrix').'</h3>'
      ),
      
      array(
        'id' => 'search_bar_enable',
        'title' => esc_html__('Search Bar Display In Header','beatrix'),
        'type' => 'switcher',
        'desc' => esc_html__('Enable or Disable Search Bar', 'beatrix') ,
        'default' => true,
      ),
      
      array(
        'id' => 'subscribe_btn_enable',
        'title' => esc_html__('Show Subscribe Button','beatrix'),
        'type' => 'switcher',
        'desc' => esc_html__('Enable or Disable Subscribe Button', 'beatrix') ,
        'default' => true,
      ), 

      array(
          'id' => 'header_btn_text_subscribe',
          'type' => 'text',
          'title' => 'Subscribe Button Text',
          'default' => esc_html__('Lets Talk', 'beatrix') ,
      ) ,

      array(
          'id' => 'header_btn_link_subscribe',
          'type' => 'text',
          'title' => 'Subscribe Button Link',
          'default' => esc_html__('#', 'beatrix') ,
      ) ,


      
      array(
        'id' => 'burger_menu_enable',
        'title' => esc_html__('Show Burger Menu Button','beatrix'),
        'type' => 'switcher',
        'desc' => esc_html__('Enable or Disable Burger Menu Button', 'beatrix') ,
        'default' => true,
      ),
      
    

    )
  ));
  


  //
  // Create a section
  CSF::createSection( $prefix.'_theme_options', array(
    'title'  => esc_html__('Color','beatrix'),
    'icon'  => 'fa fa-wrench',
    'fields' => array(

        array(
            'type' => 'subheading',
            'content' => '<h3>' . esc_html__('Choose Theme Color', 'beatrix') . '</h3>',
        ) ,

    array(
        'id' => 'theme_main_color',
        'type' => 'color',
        'title' => esc_html__('Theme Main Color', 'beatrix') ,
        'default' => '#3cffd0',
    ) ,
        
        array(
            'id' => 'theme_preloader_bg',
            'type' => 'color',
            'title' => esc_html__('Set Preloader Background Color', 'beatrix') ,
            'default' => '#000000',
                //'output'      => '#preloader',
                'output_mode' => 'background-color'

        ) ,

        array(
            'id' => 'theme_body_bg',
            'type' => 'color',
            'title' => esc_html__('Body Background Color', 'beatrix') ,
            'default' => '#131313',
                'output'      => 'body',
                'output_mode' => 'background-color'

        ) ,

        
      

    )
  ) );


    /*-------------------------------------
     ** Typography Options
     -------------------------------------*/
    CSF::createSection($prefix . '_theme_options', array(
        'title' => esc_html__('Typography', 'beatrix') ,
        'id' => 'typography_options',
        'icon' => 'fa fa-font',
        'fields' => array(

            array(
                'type' => 'subheading',
                'content' => '<h3>' . esc_html__('Body', 'beatrix') . '</h3>'
            ) ,

            array(
                'id' => 'body-typography',
                'type' => 'typography',
                'output' => 'body',
                'default' => array(
                                        'color' => '#ffffff',
                    'font-family' => 'Poppins',
                    'font-weight' => '400',
                    'font-size' => '16',
                    'line-height' => '26',
                                        'letter-spacing' => false,
                    'subset' => 'latin-ext',
                    'type' => 'google',
                    'unit' => 'px',
                ) ,

            ) ,

            array(
                'type' => 'subheading',
                'content' => '<h3>' . esc_html__('Heading h1', 'beatrix') . '</h3>'
            ) ,

            array(
                'id' => 'heading-one-typo',
                'type' => 'typography',

                'output' => 'h1',
                'default' => array(
                    'color' => '#ffffff',
                    'font-family' => 'Anton',
                    'font-weight' => '400',
                                        'font-size' => '42',
                    'line-height' => '50',
                    'subset' => 'latin-ext',
                    'type' => 'google',
                    'unit' => 'px',
                    'letter-spacing' => '0',
                ) ,
                'extra-styles' => array(
                    '300',
                    '400',
                    '500',
                    '600',
                    '700',
                    '800',
                    '900'
                ) ,
            ) ,

            array(
                'type' => 'subheading',
                'content' => '<h3>' . esc_html__('Heading h2', 'beatrix') . '</h3>'
            ) ,

            array(
                'id' => 'heading-two-typo',
                'type' => 'typography',

                'output' => 'h2',
                'default' => array(
                    'color' => '#ffffff',
                    'font-family' => 'Anton',
                    'font-weight' => '400',
                    'font-size' => '28',
                    'line-height' => '36',
                    'subset' => 'latin-ext',
                    'type' => 'google',
                    'unit' => 'px',
                    'letter-spacing' => false,
                ) ,
                'extra-styles' => array(
                    '300',
                    '400',
                    '500',
                    '600',
                    '800',
                    '900'
                ) ,
            ) ,

            array(
                'type' => 'subheading',
                'content' => '<h3>' . esc_html__('Heading h3', 'beatrix') . '</h3>'
            ) ,

            array(
                'id' => 'heading-three-typo',
                'type' => 'typography',

                'output' => 'h3',
                'default' => array(
                    'color' => '#ffffff',
                    'font-family' => 'Anton',
                    'font-weight' => '400',
                    'font-size' => '24',
                    'line-height' => '28',
                    'subset' => 'latin-ext',
                    'type' => 'google',
                    'unit' => 'px',
                    'letter-spacing' => false,
                ) ,
                'extra-styles' => array(
                    '300',
                    '400',
                    '500',
                    '600',
                    '800',
                    '900'
                ) ,
            ) ,

            array(
                'type' => 'subheading',
                'content' => '<h3>' . esc_html__('Heading h4', 'beatrix') . '</h3>'
            ) ,

            array(
                'id' => 'heading-four-typo',
                'type' => 'typography',

                'output' => 'h4',
                'default' => array(
                    'color' => '#ffffff',
                    'font-family' => 'Anton',
                    'font-weight' => '400',
                    'font-size' => '18',
                    'line-height' => '28',
                    'subset' => 'latin-ext',
                    'type' => 'google',
                    'unit' => 'px',
                    'letter-spacing' => false,
                ) ,
                'extra-styles' => array(
                    '300',
                    '400',
                    '500',
                    '600',
                    '800',
                    '900'
                ) ,
            ) ,

            array(
                'type' => 'subheading',
                'content' => '<h3>' . esc_html__('Heading h5', 'beatrix') . '</h3>'
            ) ,

            array(
                'id' => 'heading-five-typo',
                'type' => 'typography',

                'output' => 'h5',
                'default' => array(
                    'color' => '#ffffff',
                    'font-family' => 'Anton',
                    'font-weight' => '400',
                    'font-size' => '14',
                    'line-height' => '24',
                    'subset' => 'latin-ext',
                    'type' => 'google',
                    'unit' => 'px',
                    'letter-spacing' => false,
                ) ,
                'extra-styles' => array(
                    '300',
                    '400',
                    '500',
                    '600',
                    '800',
                    '900'
                ) ,
            ) ,

            array(
                'type' => 'subheading',
                'content' => '<h3>' . esc_html__('Heading h6', 'beatrix') . '</h3>'
            ) ,

            array(
                'id' => 'heading-six-typo',
                'type' => 'typography',
                'output' => 'h6',
                'default' => array(
                    'color' => '#ffffff',
                    'font-family' => 'Anton',
                    'font-weight' => '400',
                    'font-size' => '14',
                    'line-height' => '28',
                    'subset' => 'latin-ext',
                    'type' => 'google',
                    'unit' => 'px',
                    'letter-spacing' => false,
                ) ,
                'extra-styles' => array(
                    '300',
                    '400',
                    '500',
                    '600',
                    '800',
                    '900'
                ) ,
            ) ,


        )
    ));
  
  
  
  

  /*-------------------------------------------------------
     ** Pages and Template
   --------------------------------------------------------*/

   // blog optoins
    CSF::createSection( $prefix.'_theme_options', array(
    'title'  => esc_html__('Blog','beatrix'),
    'id' => 'blog_page',
    'icon' => 'fa fa-bookmark',
    'fields' => array(
      array(
        'type' => 'subheading',
        'content' =>'<h3>'.esc_html__('Blog Options','beatrix').'</h3>'
      ),
      
        array(
            'id'         => 'blog_title',
            'type'       => 'text',
            'title'      => esc_html__('Blog Page Title','beatrix'),
            'default'    => esc_html__('Blog Page','beatrix'),
            'desc'       => esc_html__('Type Blog Page Title','beatrix'),
        ),
        
        array(
            'id' => 'page-spacing-blog',
            'type' => 'spacing',
            'title' => esc_html__('Blog Page Spacing','beatrix'),
            'output' => '.main-container.blog-spacing',
            'output_mode' => 'padding', // or margin, relative
            'default' => array(
                'top' => '80',
                'right' => '0',
                'bottom' => '80',
                'left' => '0',
                'unit' => 'px',
            ) ,
        ) ,
        
        array(
            'id' => 'blog_breadcrumb_enable',
            'title' => esc_html__('Breadcrumb', 'beatrix') ,
            'type' => 'switcher',
            'desc' => esc_html__('Enable Breadcrumb', 'beatrix') ,
            'default' => true,
        ) ,
            
        

     
    )
  ));
  
  
    // category 
    
  CSF::createSection( $prefix.'_theme_options', array(
    'title'  => esc_html__('Category','beatrix'),
    'id' => 'cat_page',
    'icon' => 'fa fa-list-ul',
    'fields' => array(
      array(
        'type' => 'subheading',
        'content' => '<h3>' . esc_html__('Theme Category Options. You can Customize Each Catgeory by Editing Individually.', 'beatrix') . '</h3>'
      ),
       array(
            'id' => 'beatrix_cat_layout',
            'type' => 'image_select',
            'title' => esc_html__('Select Category Layout','beatrix'),
            'options' => array(
                'catt-one' => BEATRIX_IMG . '/admin/page/style1.png',
                'catt-two' => BEATRIX_IMG . '/admin/page/style2.png',
            ),
            'default' => 'catt-one'
        ),
        
        array(
            'id' => 'page-spacing-category',
            'type' => 'spacing',
            'title' => esc_html__('Category Page Spacing','beatrix'),
            'output' => '.main-container.cat-page-spacing',
            'output_mode' => 'padding', // or margin, relative
            'default' => array(
                'top' => '80',
                'right' => '0',
                'bottom' => '80',
                'left' => '0',
                'unit' => 'px',
            ) ,
        ) ,


    )
  ));
  
  

  // blog single optoins
    CSF::createSection( $prefix.'_theme_options', array(
    'title'  => esc_html__('Single','beatrix'),
    'id' => 'single_page',
    'icon' => 'fa fa-pencil-square-o',
    'fields' => array(
      array(
        'type' => 'subheading',
        'content' =>'<h3>'.esc_html__('Blog Single Page Option','beatrix').'</h3>'
      ),
      
       array(
            'id' => 'beatrix_single_blog_layout',
            'type' => 'image_select',
            'title' => esc_html__('Select Single Blog Style','beatrix'),
            'options' => array(
                'single-one' => BEATRIX_IMG . '/admin/page/blog-1.png',
                'single-two' => BEATRIX_IMG . '/admin/page/blog-2.png',
            ),
            'default' => 'single-one'
        ),
        
        array(
            'id' => 'page-spacing-single',
            'type' => 'spacing',
            'title' => esc_html__('Single Blog Spacing','beatrix'),
            'output' => '.single-one-bwrap',
            'output_mode' => 'padding', // or margin, relative
            'default' => array(
                'top' => '40',
                'right' => '0',
                'bottom' => '80',
                'left' => '0',
                'unit' => 'px',
            ) ,
        ) ,
        
        array(
            'id'         => 'blog_prev_title',
            'type'       => 'text',
            'title'      => esc_html__('Previous Post Text','beatrix'),
            'default'    => esc_html__('Previous Post','beatrix'),
            'desc'       => esc_html__('Type Previous Post Link Title','beatrix'),
        ),
        
        array(
            'id'         => 'blog_next_title',
            'type'       => 'text',
            'title'      => esc_html__('Next Post Text','beatrix'),
            'default'    => esc_html__('Next Post','beatrix'),
            'desc'       => esc_html__('Type Next Post Link Title','beatrix'),
        ),
            
        array(
            'id' => 'blog_single_cat',
            'title' => esc_html__('Show Catgeory','beatrix'),
            'type' => 'switcher',
            'desc' => esc_html__('Show Category Name','beatrix'),
            'default' => true,
        ),
        
        array(
            'id' => 'blog_single_author',
            'title' => esc_html__('Show Author','beatrix'),
            'type' => 'switcher',
            'desc' => esc_html__('Single Post Author','beatrix'),
            'default' => true,
        ),

        array(
            'id' => 'blog_nav',
            'title' => esc_html__('Show Navigation','beatrix'),
            'type' => 'switcher',
            'desc' => esc_html__('Post Navigation','beatrix'),
            'default' => true,
        ),
        
        array(
            'id' => 'blog_tags',
            'title' => esc_html__('Show Tags','beatrix'),
            'type' => 'switcher',
            'desc' => esc_html__('Show Post Tags','beatrix'),
            'default' => true,
        ),
        
        array(
            'id' => 'blog_related',
            'title' => esc_html__('Show Related Posts','beatrix'),
            'type' => 'switcher',
            'desc' => esc_html__('Related Posts','beatrix'),
            'default' => true,
        ),
        
        array(
            'id' => 'blog_views',
            'title' => esc_html__('Show Post Views','beatrix'),
            'type' => 'switcher',
            'desc' => esc_html__('Post views','beatrix'),
            'default' => false,
        ),


    )
  ));


    /*-------------------------------------------------------
       ** Woocommerce  Options
    --------------------------------------------------------*/
    
  CSF::createSection( $prefix.'_theme_options', array(
    'title'  => esc_html__('Shop','beatrix'),
    'id' => 'cat_page',
    'icon' => 'fa fa-pencil-square-o',
    'fields' => array(
      array(
        'type' => 'subheading',
        'content' => '<h3>' . esc_html__('Shop Layout', 'beatrix') . '</h3>'
      ),
      
      
        array(
            'id' => 'shop_layout',
            'type' => 'image_select',
            'title' => esc_html__('Shop Layout','beatrix'),
            'options' => array(
             
                'right-sidebar' => BEATRIX_IMG . '/admin/header-style/right-sidebar.png',
                'left-sidebar' => BEATRIX_IMG . '/admin/header-style/left-sidebar.png',
                'no-sidebar' => BEATRIX_IMG . '/admin/header-style/default.png',
            ),
            
            'default' => 'right-sidebar'
        ),
        
        
        array(
            'id' => 'single_shop_layout',
            'type' => 'image_select',
            'title' => esc_html__('Single Product Layout','beatrix'),
            'options' => array(
             
                'right-sidebar' => BEATRIX_IMG . '/admin/header-style/right-sidebar.png',
                'left-sidebar' => BEATRIX_IMG . '/admin/header-style/left-sidebar.png',
                'no-sidebar' => BEATRIX_IMG . '/admin/header-style/default.png',
            ),
            
            'default' => 'right-sidebar'
        ),

        array(
            'id'         => 'product_page_title',
            'type'       => 'text',
            'title'      => esc_html__('Poduct Page Title Text','beatrix'),
            'default'    => esc_html__('Product Details','beatrix'),
            'desc'       => esc_html__('Give Product Page Title Text','beatrix'),
        ),


        array(
            'id' => 'related_product_show',
            'title' => esc_html__('Show or Hide Related Products', 'beatrix') ,
            'type' => 'switcher',
            'desc' => esc_html__('Related Product Show or Hide', 'beatrix') ,
            'default' => true,
        ) ,




        )
    )); 
    
    
  /*-------------------------------------------------------
       ** Footer  Options
  --------------------------------------------------------*/
  CSF::createSection( $prefix.'_theme_options', array(
    'title'  => esc_html__('Footer','beatrix'),
    'id' => 'footer_options',
    'icon' => 'fa fa-copyright',
    'fields' => array(
      array(
        'type' => 'subheading',
        'content' =>'<h3>'.esc_html__('Footer Options','beatrix').'</h3>'
      ),
      
    array(
        'id' => 'footer_nav',
        'title' => esc_html__('Footer Right Menu','beatrix'),
        'type' => 'switcher',
        'desc' => esc_html__('You can set Yes or No to show Footer menu','beatrix'),
        'default' => false,
      ),
      
      
      array(
        'type' => 'subheading',
        'content' =>'<h3>'.esc_html__('Footer Copyright Area Options','beatrix').'</h3>'
      ),

      array(
        'id' => 'copyright_text',
        'title' => esc_html__('Copyright Area Text','beatrix'),
        'type' => 'textarea',
        'desc' => esc_html__('Footer Copyright Text','beatrix'),
      ),


      
    )
  ));


  // Backup section
  CSF::createSection( $prefix.'_theme_options', array(
    'title'  => esc_html__('Backup','beatrix'),
    'id'    => 'backup_options',
    'icon'  => 'fa fa-window-restore',
    'fields' => array(
        array(
            'type' => 'backup',
        ),   
    )
  ) );
  

}