<?php

/**
 * Elementor Widget
 * @package Beatrix
 * @since 1.0.0
 */


if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly.

class beatrix_post_block_list_one extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'posts-block-list-onee';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Post Block List 1', 'beatrix-extra' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Elementor widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fas fa-th-large'; 
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Elementor widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'beatrix_widgets' ];
	}

	/**
	 * Register Elementor widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	 
	
	protected function register_controls() {


		/**
	    * Layout Options
	    */

		$this->start_controls_section(
            'layout_option',
            [
                'label' => __( 'Layout Options', 'beatrix-extra' ),
                'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );
		

		$this->add_responsive_control(
			'grid_img_height',
			[
				'label' =>esc_html__( 'Set Post Image Height', 'beatrix-extra' ),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1000,
					],
				],

				'devices' => [ 'desktop', 'tablet', 'mobile' ],

				'desktop_default' => [
					'size' => 105,
					'unit' => 'px',
				],
				'tablet_default' => [
					'size' => 300,
					'unit' => 'px',
				],
				'mobile_default' => [
					'size' => 350,
					'unit' => 'px',
				],
				
				'default'  => [
					'unit' => 'px',
					'size' => 105,
				],
				
				'selectors' => [
					'{{WRAPPER}} .post-list-one-main-wrapper .post-block-template-two .post-block-media-wrap a img ' => 'height: {{SIZE}}{{UNIT}};',
				],
			]
		);		
		
		
		$this->end_controls_section();



		/**
		* Post Query Options
		*/

		$this->start_controls_section(
            'post_query_option',
            [
                'label' => __( 'Post Options', 'beatrix-extra' ),
                'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );
		
		
		// Post Sort
		
        $this->add_control(
            'post_sorting',
            [
                'type'    => \Elementor\Controls_Manager::SELECT2,
                'label' => esc_html__('Post Sorting', 'beatrix-extra'),
                'default' => 'date',
                'options' => [
					'date' => esc_html__('Recent Post', 'beatrix-extra'),
                    'rand' => esc_html__('Random Post', 'beatrix-extra'),
					'title'         => __( 'Title Sorting Post', 'beatrix-extra' ),
                    'modified' => esc_html__('Last Modified Post', 'beatrix-extra'),
                    'comment_count' => esc_html__('Most Commented Post', 'beatrix-extra'),
					
                ],
            ]
        );		
		
		// Post Order
		
        $this->add_control(
            'post_ordering',
            [
                'type'    => \Elementor\Controls_Manager::SELECT2,
                'label' => esc_html__('Post Ordering', 'beatrix-extra'),
                'default' => 'DESC',
                'options' => [
					'DESC' => esc_html__('Desecending', 'beatrix-extra'),
                    'ASC' => esc_html__('Ascending', 'beatrix-extra'),
                ],
            ]
        );
		
		
		// Post Categories
		
		$this->add_control(
            'post_categories',
            [
                'type'      => \Elementor\Controls_Manager::SELECT2,
				'label' =>esc_html__('Select Categories', 'beatrix-extra'),
                'options'   => $this->posts_cat_list(),
                'label_block' => true,
                'multiple'  => true,
            ]
        );
	
		
		
		// Post Items.
		
        $this->add_control(
            'post_number',
			[
				'label'         => esc_html__( 'Number Of Posts', 'beatrix-extra' ),
				'type'          => \Elementor\Controls_Manager::NUMBER,
				'default'       => '2',
			]
        );
		
		$this->add_control(
            'enable_offset_post',
            [
               'label' => esc_html__('Enable Skip Post', 'beatrix-extra'),
               'type' => \Elementor\Controls_Manager::SWITCHER,
               'label_on' => esc_html__('Yes', 'beatrix-extra'),
               'label_off' => esc_html__('No', 'beatrix-extra'),
               'default' => 'no',
               
            ]
        );
      
        $this->add_control(
			'post_offset_count',
			  [
			   'label'         => esc_html__( 'Skip Post Count', 'beatrix-extra' ),
			   'type'          => \Elementor\Controls_Manager::NUMBER,
			   'default'       => '1',
			   'condition' => [ 'enable_offset_post' => 'yes' ]

			  ]
        );
		
		
		$this->end_controls_section();


	
		/**
		* Meta Options
		*/

	
		$this->start_controls_section(
            'meta_option',
            [
                'label' => __( 'Meta Options', 'beatrix-extra' ),
                'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );
		
		$this->add_control(
            'display_excerpt',
            [
                'label' => esc_html__('Display Post Excerpt', 'ennlil-extra'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => esc_html__('Yes', 'ennlil-extra'),
                'label_off' => esc_html__('No', 'ennlil-extra'),
                'default' => 'yes',
            ]
        );

		$this->add_control(
         	'display_author',
         	[
				 'label' => esc_html__('Display Author', 'beatrix-extra'),
				 'type' => \Elementor\Controls_Manager::SWITCHER,
				 'label_on' => esc_html__('Yes', 'beatrix-extra'),
				 'label_off' => esc_html__('No', 'beatrix-extra'),
				 'default' => 'yes',
         	]
     	);

     	$this->add_control(
            'display_cat',
            [
                'label' => esc_html__('Display Category Name', 'beatrix-extra'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => esc_html__('Yes', 'beatrix-extra'),
                'label_off' => esc_html__('No', 'beatrix-extra'),
                'default' => 'yes',
            ]
        );

		
		$this->add_control(
            'display_date',
            [
                'label' => esc_html__('Display Date', 'beatrix-extra'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => esc_html__('Yes', 'beatrix-extra'),
                'label_off' => esc_html__('No', 'beatrix-extra'),
                'default' => 'yes',
            ]
        );
		
		

 
		
	
		$this->end_controls_section();

		/**
		* Design Options
		*/
	
	
		$this->start_controls_section(
            'design_option',
            [
                'label' => __( 'Typography', 'beatrix-extra' ),
                'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );
		

		$this->add_group_control(
           \Elementor\Group_Control_Typography::get_type(),
           [
              'name' => 'list_one_title_typography',
              'label' => esc_html__( 'Post Title Typography', 'beatrix-extra' ),
              'selector' => '{{WRAPPER}} .post-list-one-main-wrapper .post-block-template-two .post-block-content-wrap h2.post-title',
           ]
        );		

        $this->add_responsive_control(
            'list_one_title_margin',
            [
                'label' => esc_html__( 'Title Margin', 'restlycore' ),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .post-list-one-main-wrapper .post-block-template-two .post-block-content-wrap h2.post-title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
		
		
		// $this->add_group_control(
  //          \Elementor\Group_Control_Typography::get_type(),
  //          [
  //             'name' => 'block_one_excerpt_typography',
  //             'label' => esc_html__( 'Post Excerpt Typography', 'beatrix-extra' ),
  //             'selector' => '{{WRAPPER}} .post-block-main-one-wrap.post-block-style-wrapper .post-block-content-wrap .post-excerpt-box p',
  //          ]
  //       );	

        // $this->add_responsive_control(
        //     'block_one_excerpt_margin',
        //     [
        //         'label' => esc_html__( 'Excerpt Margin', 'restlycore' ),
        //         'type' => \Elementor\Controls_Manager::DIMENSIONS,
        //         'size_units' => [ 'px', '%', 'em' ],
        //         'selectors' => [
        //             '{{WRAPPER}} .post-block-main-one-wrap.post-block-style-wrapper .post-block-content-wrap .post-excerpt-box' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        //         ],
        //     ]
        // );

		
		$this->add_control('block_one_title_color', [
            'label' => esc_html__('Post Title Color', 'senatory-master'),
            'type' => \Elementor\Controls_Manager::COLOR,
            'selectors' => [
                "{{WRAPPER}} .post-list-one-main-wrapper .post-block-template-two .post-block-content-wrap h2.post-title" => "color: {{VALUE}}"
            ]
        ]);

        // $this->add_control('block_one_excerpt_color', [
        //     'label' => esc_html__('Post Title Color', 'senatory-master'),
        //     'type' => \Elementor\Controls_Manager::COLOR,
        //     'selectors' => [
        //         "{{WRAPPER}} .post-block-main-one-wrap.post-block-style-wrapper .post-block-content-wrap .post-excerpt-box p" => "color: {{VALUE}}"
        //     ]
        // ]);
		
		
		$this->add_group_control(
           \Elementor\Group_Control_Typography::get_type(),
           [
              'name' => 'cat_typography',
              'label' => esc_html__( 'Post Category Typography', 'beatrix-extra' ),
              'selector' => '{{WRAPPER}} .post-list-one-main-wrapper .post-category-box a',
           ]
        );

        $this->add_control('list_one_cat_color', [
            'label' => esc_html__('Post Title Color', 'senatory-master'),
            'type' => \Elementor\Controls_Manager::COLOR,
            'selectors' => [
                "{{WRAPPER}} .post-list-one-main-wrapper .post-category-box a" => "color: {{VALUE}}"
            ]
        ]);


        $this->add_group_control(
           \Elementor\Group_Control_Typography::get_type(),
           [
              'name' => 'meta_typography',
              'label' => esc_html__( 'Post Meta Typography', 'beatrix-extra' ),
              'selector' => '{{WRAPPER}} .post-list-one-main-wrapper .post-block-template-two .post-block-content-wrap .post-bottom-meta-list',
           ]
        );

		
		$this->add_control(
          'title_length',
          [
            'label'         => esc_html__( 'Post Title Length', 'beatrix-extra' ),
            'type'          => \Elementor\Controls_Manager::NUMBER,
            'default'       => '10',
          ]
        );


        $this->add_control(
          'content_length',
          [
            'label'         => esc_html__( 'Post Excerpt Length', 'ennlil-extra' ),
            'type'          => \Elementor\Controls_Manager::NUMBER,
            'default'       => '20',
          ]
        );
		
		
		$this->end_controls_section();



	}
	

	protected function render() {
		
		
		$settings = $this->get_settings_for_display();

		$title_limit = $settings['title_length'];
		$content_limit = $settings['content_length'];
		$post_count = $settings['post_number'];
		$post_order  = $settings['post_ordering'];
		$post_sortby = $settings['post_sorting']; 

		$display_blog_excerpt = $settings['display_excerpt'];
		$display_blog_cat = $settings['display_cat'];
		$display_blog_author = $settings['display_author'];
		$display_blog_date = $settings['display_date'];

	

		
		$args = [
            'post_type' => 'post',
            'post_status' => 'publish',
			'order' => $settings['post_ordering'],
			'posts_per_page' => $settings['post_number'],
			'ignore_sticky_posts' => 1,
        ];
		
		// Category
        if ( ! empty( $settings['post_categories'] ) ) {
            $args['category_name'] = implode(',', $settings['post_categories']);
        }
		
		// Post Sorting
        if ( ! empty( $settings['post_sorting'] ) ) {
            $args['orderby'] = $settings['post_sorting'];
        }	
		
		// Post Offset		
		if($settings['enable_offset_post'] == 'yes') {
			$args['offset'] = $settings['post_offset_count'];
		}


		// Query
        $query = new \WP_Query( $args ); ?>
		

		<div class="post-list-one-main-wrapper">
			
		
		<div class="section-title sm-mt-24">
            <h2 class="title-block">
                Todays Pick
            </h2>
        </div>

        <div class="post-block-template-two-wrapper">
        	
        	
		
		<?php if ( $query->have_posts() ) : ?>

			<?php while ($query->have_posts()) : $query->the_post(); ?>



			<article class="post-block-style-wrapper post-block-template-two">

                <div class="post-block-style-inner post-block-list-style-inner">

                    <div class="post-block-media-wrap">

                        <a href="<?php the_permalink(); ?>">

                        <img src="<?php echo esc_attr(esc_url(get_the_post_thumbnail_url(null, 'full'))); ?>" alt="<?php the_title_attribute(); ?>">

                        </a>

                    </div>

                    <div class="post-block-content-wrap">

                    	<?php if($display_blog_cat=='yes'): ?>	

                        <div class="post-category-box">

                            <?php require BEATRIX_THEME_DIR . '/template-parts/cat-alt-template.php'; ?>

                        </div>

                        <?php endif; ?>

                        <div class="post-item-title">
                            <h2 class="post-title">
                                <a href="<?php the_permalink(); ?>">
                                	<?php echo esc_html( wp_trim_words(get_the_title(), $title_limit,'') ); ?>
                                </a>
                            </h2>
                        </div>



                        <div class="post-bottom-meta-list">
                            
                            <?php if($display_blog_author=='yes'): ?>
                            <div class="post-meta-author-box">
                               <?php echo get_the_author_link(); ?>
                            </div>
                            <?php endif; ?>

                           
                            <?php if($display_blog_date=='yes'): ?>
                            <div class="post-meta-date-box">
                                <?php echo esc_html( get_the_date( 'F j, Y' ) ); ?>
                            </div>
                            <?php endif; ?>

                        </div>


                    </div>
                </div>
            </article>



			<?php endwhile; ?>
		
		<?php wp_reset_postdata(); ?>
		
		<?php endif; ?>

	</div>	

	</div>

	
	<?php 
}
		
   
   	public function posts_cat_list() {
		
		$terms = get_terms( array(
			'taxonomy'    => 'category',
			'hide_empty'  => true
		) );

		$cat_list = [];
		foreach($terms as $post) {
		$cat_list[$post->slug]  = [$post->name];
		}
		return $cat_list;
	  
	}		
	
}
