<?php

/**
 * Elementor Widget
 * @package Beatrix
 * @since 1.0.0
 */


if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly.

class beatrix_post_block_template_video extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'posts-block-item-video';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Post Block Video', 'beatrix-extra' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Elementor widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'fas fa-th-large'; 
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Elementor widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'beatrix_widgets' ];
	}

	/**
	 * Register Elementor widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	 
	
	protected function register_controls() {


		/**
	    * Layout Options
	    */

		$this->start_controls_section(
            'layout_option',
            [
                'label' => __( 'Layout Options', 'beatrix-extra' ),
                'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );
		

		$this->add_responsive_control(
			'grid_img_height',
			[
				'label' =>esc_html__( 'Set Post Image Height', 'beatrix-extra' ),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 1000,
					],
				],

				'devices' => [ 'desktop', 'tablet', 'mobile' ],

				'desktop_default' => [
					'size' => 405,
					'unit' => 'px',
				],
				'tablet_default' => [
					'size' => 400,
					'unit' => 'px',
				],
				'mobile_default' => [
					'size' => 350,
					'unit' => 'px',
				],
				
				'default'  => [
					'unit' => 'px',
					'size' => 405,
				],
				
				'selectors' => [
					'{{WRAPPER}} .post-block-template-video-wrapper .post-block-video .post-block-media-wrap a img' => 'height: {{SIZE}}{{UNIT}};',
				],
			]
		);		
		
		
		$this->end_controls_section();



		/**
		* Post Query Options
		*/

		$this->start_controls_section(
            'post_query_option',
            [
                'label' => __( 'Post Options', 'beatrix-extra' ),
                'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );
		
		
		// Post Sort
		
        $this->add_control(
            'post_sorting',
            [
                'type'    => \Elementor\Controls_Manager::SELECT2,
                'label' => esc_html__('Post Sorting', 'beatrix-extra'),
                'default' => 'date',
                'options' => [
					'date' => esc_html__('Recent Post', 'beatrix-extra'),
                    'rand' => esc_html__('Random Post', 'beatrix-extra'),
					'title'         => __( 'Title Sorting Post', 'beatrix-extra' ),
                    'modified' => esc_html__('Last Modified Post', 'beatrix-extra'),
                    'comment_count' => esc_html__('Most Commented Post', 'beatrix-extra'),
					
                ],
            ]
        );		
		
		// Post Order
		
        $this->add_control(
            'post_ordering',
            [
                'type'    => \Elementor\Controls_Manager::SELECT2,
                'label' => esc_html__('Post Ordering', 'beatrix-extra'),
                'default' => 'DESC',
                'options' => [
					'DESC' => esc_html__('Desecending', 'beatrix-extra'),
                    'ASC' => esc_html__('Ascending', 'beatrix-extra'),
                ],
            ]
        );
		
		
		// Post Categories
		
		$this->add_control(
            'post_categories',
            [
                'type'      => \Elementor\Controls_Manager::SELECT2,
				'label' =>esc_html__('Select Categories', 'beatrix-extra'),
                'options'   => $this->posts_cat_list(),
                'label_block' => true,
                'multiple'  => true,
            ]
        );
	
		
		
		// Post Items.
		
        $this->add_control(
            'post_number',
			[
				'label'         => esc_html__( 'Number Of Posts', 'beatrix-extra' ),
				'type'          => \Elementor\Controls_Manager::NUMBER,
				'default'       => '2',
			]
        );
		
		$this->add_control(
            'enable_offset_post',
            [
               'label' => esc_html__('Enable Skip Post', 'beatrix-extra'),
               'type' => \Elementor\Controls_Manager::SWITCHER,
               'label_on' => esc_html__('Yes', 'beatrix-extra'),
               'label_off' => esc_html__('No', 'beatrix-extra'),
               'default' => 'no',
               
            ]
        );
      
        $this->add_control(
			'post_offset_count',
			  [
			   'label'         => esc_html__( 'Skip Post Count', 'beatrix-extra' ),
			   'type'          => \Elementor\Controls_Manager::NUMBER,
			   'default'       => '1',
			   'condition' => [ 'enable_offset_post' => 'yes' ]

			  ]
        );
		
		
		$this->end_controls_section();


	
		/**
		* Meta Options
		*/

	
		$this->start_controls_section(
            'meta_option',
            [
                'label' => __( 'Meta Options', 'beatrix-extra' ),
                'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
            ]
        );
		
		$this->add_control(
            'display_excerpt',
            [
                'label' => esc_html__('Display Post Excerpt', 'ennlil-extra'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => esc_html__('Yes', 'ennlil-extra'),
                'label_off' => esc_html__('No', 'ennlil-extra'),
                'default' => 'no',
            ]
        );

		$this->add_control(
         	'display_author',
         	[
				 'label' => esc_html__('Display Author', 'beatrix-extra'),
				 'type' => \Elementor\Controls_Manager::SWITCHER,
				 'label_on' => esc_html__('Yes', 'beatrix-extra'),
				 'label_off' => esc_html__('No', 'beatrix-extra'),
				 'default' => 'yes',
         	]
     	);

     	$this->add_control(
            'display_cat',
            [
                'label' => esc_html__('Display Category Name', 'beatrix-extra'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => esc_html__('Yes', 'beatrix-extra'),
                'label_off' => esc_html__('No', 'beatrix-extra'),
                'default' => 'no',
            ]
        );

		
		$this->add_control(
            'display_date',
            [
                'label' => esc_html__('Display Date', 'beatrix-extra'),
                'type' => \Elementor\Controls_Manager::SWITCHER,
                'label_on' => esc_html__('Yes', 'beatrix-extra'),
                'label_off' => esc_html__('No', 'beatrix-extra'),
                'default' => 'yes',
            ]
        );
		
		

 
		
	
		$this->end_controls_section();

		/**
		* Design Options
		*/
	
	
		$this->start_controls_section(
            'design_option',
            [
                'label' => __( 'Slider Typography', 'beatrix-extra' ),
                'tab'   => \Elementor\Controls_Manager::TAB_STYLE,
            ]
        );
		

		$this->add_group_control(
           \Elementor\Group_Control_Typography::get_type(),
           [
              'name' => 'block_one_title_typography',
              'label' => esc_html__( 'Post Title Typography', 'beatrix-extra' ),
              'selector' => '{{WRAPPER}} .post-block-template-video-wrapper .post-block-video .post-block-content-wrap h2.post-title',
           ]
        );		

        $this->add_responsive_control(
            'block_one_title_margin',
            [
                'label' => esc_html__( 'Title Margin', 'restlycore' ),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .post-block-template-video-wrapper .post-block-video .post-block-content-wrap h2.post-title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
		
		
		$this->add_group_control(
           \Elementor\Group_Control_Typography::get_type(),
           [
              'name' => 'block_one_excerpt_typography',
              'label' => esc_html__( 'Post Excerpt Typography', 'beatrix-extra' ),
              'selector' => '{{WRAPPER}} .post-block-template-video-wrapper .post-block-video .post-block-content-wrap .post-excerpt-box p',
           ]
        );	

        $this->add_responsive_control(
            'block_one_excerpt_margin',
            [
                'label' => esc_html__( 'Excerpt Margin', 'restlycore' ),
                'type' => \Elementor\Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .post-block-template-video-wrapper .post-block-video .post-block-content-wrap .post-excerpt-box' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

		
		$this->add_control('block_one_title_color', [
            'label' => esc_html__('Post Title Color', 'senatory-master'),
            'type' => \Elementor\Controls_Manager::COLOR,
            'selectors' => [
                "{{WRAPPER}} .post-block-template-video-wrapper .post-block-video .post-block-content-wrap h2.post-title a" => "color: {{VALUE}}"
            ]
        ]);

        $this->add_control('block_one_excerpt_color', [
            'label' => esc_html__('Post Title Color', 'senatory-master'),
            'type' => \Elementor\Controls_Manager::COLOR,
            'selectors' => [
                "{{WRAPPER}} .post-block-template-video-wrapper .post-block-video .post-block-content-wrap .post-excerpt-box p" => "color: {{VALUE}}"
            ]
        ]);
		
		
		$this->add_group_control(
           \Elementor\Group_Control_Typography::get_type(),
           [
              'name' => 'meta_typography',
              'label' => esc_html__( 'Post Meta Typography', 'beatrix-extra' ),
              'selector' => '{{WRAPPER}} .post-block-template-video-wrapper .post-block-video .post-bottom-meta-list',
           ]
        );

		
		$this->add_control(
          'title_length',
          [
            'label'         => esc_html__( 'Post Title Length', 'beatrix-extra' ),
            'type'          => \Elementor\Controls_Manager::NUMBER,
            'default'       => '10',
          ]
        );


        $this->add_control(
          'content_length',
          [
            'label'         => esc_html__( 'Post Excerpt Length', 'ennlil-extra' ),
            'type'          => \Elementor\Controls_Manager::NUMBER,
            'default'       => '20',
          ]
        );
		
		
		$this->end_controls_section();



	}
	

	protected function render() {
		
		
		$settings = $this->get_settings_for_display();

		$title_limit = $settings['title_length'];
		$content_limit = $settings['content_length'];
		$post_count = $settings['post_number'];
		$post_order  = $settings['post_ordering'];
		$post_sortby = $settings['post_sorting']; 

		$display_blog_excerpt = $settings['display_excerpt'];
		$display_blog_cat = $settings['display_cat'];
		$display_blog_author = $settings['display_author'];
		$display_blog_date = $settings['display_date'];


        $args = [
            'post_type' => 'post',
            'post_status' => 'publish',
			'ignore_sticky_posts' => 1,
			'tax_query' => [[
                'taxonomy' => 'post_format',
                'field' => 'slug',
                'terms' => array( 'post-format-video'),
                'operator' => 'IN'
            ]]
        ];

		// How many posts
        if ( ! empty( $settings['post_number'] ) ) {
            $args['posts_per_page'] = $settings['post_number'];
        }

		// Category
        if ( ! empty( $settings['post_categories'] ) ) {
            $args['category_name'] = implode(',', $settings['post_categories']);
        }
		
		// Post Sorting
        if ( ! empty( $settings['post_sorting'] ) ) {
            $args['orderby'] = $settings['post_sorting'];
        }	

        // Post Ordering
        if ( ! empty( $settings['post_ordering'] ) ) {
            $args['order'] = $settings['post_ordering'];
        }	
		
		
		// Post Offset		
		if($settings['enable_offset_post'] == 'yes') {
			$args['offset'] = $settings['post_offset_count'];
		}


		// Query
        $query = new \WP_Query( $args ); ?>
		
		<div class="post-block-template-video-wrapper">

		<?php if ( $query->have_posts() ) : ?>

			<?php while ($query->have_posts()) : $query->the_post(); ?>

            <article class="post-block-style-wrapper post-block-template-one post-block-video">
                <div class="post-block-style-inner">
                    <div class="post-block-video-thumb">

                        <div class="post-block-media-wrap">

                            <a href="<?php the_permalink(); ?>">
								<img src="<?php echo esc_attr(esc_url(get_the_post_thumbnail_url(null, 'full'))); ?>" alt="<?php the_title_attribute(); ?>">
							</a>

                        </div>

<div class="video-play-icon-wrap">
<a href="<?php $theme_video_meta = get_post_meta(get_the_ID(),'theme_postvideo_options',true); $video_url = isset($theme_video_meta['textm']) && !empty($theme_video_meta['textm']) ? $theme_video_meta['textm'] : ''; echo esc_url($video_url);?>" class="theme-play-btn video-play-btn">
<i class="icofont-ui-play" aria-hidden="true"></i></a>
</div>

					


                    </div>

                    <div class="post-block-content-wrap">
                        <div class="post-item-title">
                            <h2 class="post-title">
                                <a href="<?php the_permalink(); ?>">
                                	<?php echo esc_html( wp_trim_words(get_the_title(), $title_limit,'') ); ?>
                                </a>
                            </h2>
                        </div>

                        <?php if($display_blog_excerpt =='yes'): ?> 
                        <div class="post-excerpt-box">
							 <p><?php echo esc_html( wp_trim_words(get_the_excerpt(), $content_limit ,'') );?></p>
						</div>
						<?php endif; ?>


                    </div>
                </div>
            </article>



			<?php endwhile; ?>
		
		<?php wp_reset_postdata(); ?>
		
		<?php endif; ?>

		</div>

	
	<?php 
}
		
   
   	public function posts_cat_list() {
		
		$terms = get_terms( array(
			'taxonomy'    => 'category',
			'hide_empty'  => true
		) );

		$cat_list = [];
		foreach($terms as $post) {
		$cat_list[$post->slug]  = [$post->name];
		}
		return $cat_list;
	  
	}		
	
}
